#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
wagtailgeowidget
----------
A Google Maps widget for Wagtail that supports both GeoDjango PointField, StreamField and the standard CharField.
"""
__title__ = "wagtailgeowidget"
__version__ = "3.1.4"
__build__ = 314
__author__ = "Martin Sandström"
__license__ = "MIT"
__copyright__ = "Copyright 2015-2017 Fröjd Interactive"
